@@ -9,34 +9,34 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.utils import formataddr, getaddresses
 from urllib.parse import (
-    urlsplit, parse_qsl, urlencode, urlunsplit, quote, urljoin)
+    parse_qsl, quote, urlencode, urljoin, urlsplit, urlunsplit)
 
 try:
     import html2text
 except ImportError:
     html2text = None
 
+from genshi.core import END, START, Attrs, QName
+from genshi.template import MarkupTemplate, TextTemplate
 from sql import Literal
 from sql.aggregate import Count
-from sql.functions import Substring, Position
-from genshi.template import MarkupTemplate, TextTemplate
-from genshi.core import START, END, QName, Attrs
+from sql.functions import Position, Substring
 
 from trytond.config import config
 from trytond.i18n import gettext
-from trytond.model import (fields, ModelSQL, ModelView, Workflow, Unique,
-    EvalEnvironment, dualmethod)
+from trytond.model import (
+    EvalEnvironment, ModelSQL, ModelView, Unique, Workflow, dualmethod, fields)
 from trytond.pool import Pool
-from trytond.pyson import PYSONDecoder, Eval, If
+from trytond.pyson import Eval, If, PYSONDecoder
 from trytond.report import Report
-from trytond.sendmail import sendmail_transactional, SMTPDataManager
+from trytond.sendmail import SMTPDataManager, sendmail_transactional
 from trytond.tools import grouped_slice, reduce_ids
 from trytond.tools.email_ import set_from_header
 from trytond.transaction import Transaction
 from trytond.url import http_host
 from trytond.wsgi import Base64Converter
 
-from .exceptions import DomainError, ConditionError, TemplateError
+from .exceptions import ConditionError, DomainError, TemplateError
 from .mixin import MarketingAutomationMixin
 
 if not config.get(
@@ -76,7 +76,7 @@ class Scenario(Workflow, ModelSQL, ModelView):
             ('draft', "Draft"),
             ('running', "Running"),
             ('stopped', "Stopped"),
-            ], "State", required=True, readonly=True)
+            ], "State", required=True, readonly=True, sort=False)
 
     @classmethod
     def __setup__(cls):
@@ -156,13 +156,15 @@ class Scenario(Workflow, ModelSQL, ModelView):
         return count
 
     @classmethod
-    def validate(cls, scenarios):
-        super().validate(scenarios)
+    def validate_fields(cls, scenarios, field_names):
+        super().validate_fields(scenarios, field_names)
         cls.check_domain(scenarios)
 
     @classmethod
-    def check_domain(cls, scenarios):
+    def check_domain(cls, scenarios, field_names=None):
         pool = Pool()
+        if field_names and not (field_names & {'model', 'domain'}):
+            return
         for scenario in scenarios:
             Model = pool.get(scenario.model)
             try:
@@ -270,7 +272,6 @@ class Activity(ModelSQL, ModelView):
         states={
             'invisible': ~Eval('event'),
             },
-        depends=['event'],
         help="Check to execute the activity "
         "if the event has not happened by the end of the delay.")
     on = fields.Function(fields.Selection([
@@ -291,7 +292,6 @@ class Activity(ModelSQL, ModelView):
         states={
             'required': Eval('negative', False),
             },
-        depends=['negative'],
         help="After how much time the action should be executed.")
 
     action = fields.Selection([
@@ -304,7 +304,6 @@ class Activity(ModelSQL, ModelView):
         states={
             'invisible': Eval('action') != 'send_email',
             },
-        depends=['action'],
         help="Leave empty to use the value defined in the configuration file.")
     email_title = fields.Char(
         "E-Mail Title",
@@ -313,7 +312,6 @@ class Activity(ModelSQL, ModelView):
             'invisible': Eval('action') != 'send_email',
             'required': Eval('action') == 'send_email',
             },
-        depends=['action'],
         help="The subject of the email.\n"
         "The Genshi syntax can be used "
         "with 'record' in the evaluation context.")
@@ -324,7 +322,6 @@ class Activity(ModelSQL, ModelView):
             'invisible': Eval('action') != 'send_email',
             'required': Eval('action') == 'send_email',
             },
-        depends=['action'],
         help="The HTML content of the E-mail.\n"
         "The Genshi syntax can be used "
         "with 'record' in the evaluation context.")
@@ -336,15 +333,14 @@ class Activity(ModelSQL, ModelView):
             "E-Mails Opened",
             states={
                 'invisible': Eval('action') != 'send_email',
-                },
-            depends=['action']), 'get_record_count')
+                }), 'get_record_count')
     email_clicked = fields.Function(
         fields.Integer(
             "E-Mails Clicked",
             states={
                 'invisible': Eval('action') != 'send_email',
-                },
-            depends=['action']), 'get_record_count')
+                }),
+        'get_record_count')
 
     @classmethod
     def __setup__(cls):
@@ -359,7 +355,6 @@ class Activity(ModelSQL, ModelView):
                     [(name, 'in', events + [None])],
                     domain)
             field.domain = [domain]
-            field.depends = ['parent_action']
 
     @classmethod
     def view_attributes(cls):
@@ -442,14 +437,16 @@ class Activity(ModelSQL, ModelView):
         return count
 
     @classmethod
-    def validate(cls, activities):
-        super().validate(activities)
+    def validate_fields(cls, activities, fields_names):
+        super().validate_fields(activities, fields_names)
         for activity in activities:
-            activity.check_condition()
-            activity.check_email_title()
-            activity.check_email_template()
+            activity.check_condition(fields_names)
+            activity.check_email_title(fields_names)
+            activity.check_email_template(fields_names)
 
-    def check_condition(self):
+    def check_condition(self, fields_names=None):
+        if fields_names and 'condition' not in fields_names:
+            return
         if not self.condition:
             return
         try:
@@ -461,7 +458,9 @@ class Activity(ModelSQL, ModelView):
                     activity=self.rec_name,
                     exception=exception)) from exception
 
-    def check_email_template(self):
+    def check_email_template(self, fields_names=None):
+        if fields_names and 'email_template' not in fields_names:
+            return
         if not self.email_template:
             return
         try:
@@ -473,7 +472,9 @@ class Activity(ModelSQL, ModelView):
                     activity=self.rec_name,
                     exception=exception)) from exception
 
-    def check_email_title(self):
+    def check_email_title(self, fields_names=None):
+        if fields_names and 'email_title' not in fields_names:
+            return
         if not self.email_title:
             return
         try:
@@ -736,25 +737,22 @@ class RecordActivity(Workflow, ModelSQL, ModelView):
         "At",
         states={
             'readonly': Eval('state') != 'waiting',
-            },
-        depends=['state'])
+            })
     email_opened = fields.Boolean(
         "E-Mail Opened",
         states={
             'invisible': Eval('activity_action') != 'send_email',
-            },
-        depends=['activity_action'])
+            })
     email_clicked = fields.Boolean(
         "E-Mail Clicked",
         states={
             'invisible': Eval('activity_action') != 'send_email',
-            },
-        depends=['activity_action'])
+            })
     state = fields.Selection([
             ('waiting', "Waiting"),
             ('done', "Done"),
             ('cancelled', "Cancelled"),
-            ], "State", required=True, readonly=True)
+            ], "State", required=True, readonly=True, sort=False)
 
     @classmethod
     def __setup__(cls):
