@@ -1,11 +1,11 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from werkzeug.wrappers import Response
 from werkzeug.utils import redirect
+from werkzeug.wrappers import Response
 
-from trytond.transaction import Transaction
-from trytond.tools import file_open
 from trytond.protocols.wrappers import with_pool, with_transaction
+from trytond.tools import file_open
+from trytond.transaction import Transaction
 from trytond.wsgi import app
 
 
@@ -21,12 +21,12 @@ def unsubscribe(request, pool):
     record.block()
     next_ = request.args.get('next')
     if next_:
-        redirect(next_)
+        return redirect(next_)
     data = {
         'model': Record.__name__,
         }
     with Transaction().set_context(language=record.language):
-        ext, content, _, _ = Report.execute([record], data)
+        ext, content, _, _ = Report.execute([record.id], data)
     assert ext == 'html'
     return Response(content, 200, content_type='text/html')
 
